@@ -11,13 +11,18 @@ class PelicanMathExtension(markdown.Extension):
         self.settings = settings
 
     def extendMarkdown(self, md: markdown.core.Markdown):
+        md.registerExtension(self)
         md.inlinePatterns.register(
             InlineMathProcessor(
-                r"(?<!\\|\$)\$((?:[^$]|\\\$)+)(?<!\\)\$(?!\$)", self.settings, md
+                r"(?<!\\|\$)\$((?:[^$]|\\\$)+)(?<!\\)\$(?!\$)",
+                self.settings,
+                md,
             ),
             "inline_math",
             200,
         )
         md.parser.blockprocessors.register(
-            DisplayMathProcessor(self.settings, md.parser), "display_math", 200
+            DisplayMathProcessor(self.settings, md.parser),
+            "display_math",
+            200,
         )
